@@ -305,7 +305,7 @@ class WebSiteScarperWorker(WorkerAbstract):
                 file_name = action_params['to']
 
             if file_name_prefix:
-                if '$' in file_name_prefix:
+                if file_name_prefix and type(file_name_prefix) == str and file_name_prefix.startswith('$'):
                     file_name_prefix = self.execution_vars[file_name_prefix[1:]]
                 file_name = file_name_prefix+"_"+file_name
 
@@ -335,14 +335,14 @@ class WebSiteScarperWorker(WorkerAbstract):
             var_key = action_params['varKey'] if 'varKey' in action_params else None
 
 
-            if var_key and '$' in var_key:
+            if var_key and type(var_key) == str and  var_key.startswith('$'):
                 if var_key == '$.':
                     var_key = target_value
                 else:
                     var_key = self.execution_vars[var_key[1:]]
 
             var_value = action_params['varValue'] if 'varValue' in action_params else target_value
-            if '$' in var_value:
+            if var_value and type(var_value) == str and var_value.startswith('$'):
                 var_value = self.execution_vars[var_value[1:]]
             if var_type == 'list':
                 self.execution_vars[var_name].append(var_value)
@@ -358,10 +358,10 @@ class WebSiteScarperWorker(WorkerAbstract):
             var_type = action_params['varType']
             var_key = action_params['varKey'] if 'varKey' in action_params else None
             var_value = action_params['varValue'] if 'varValue' in action_params else target_value
-            if '$' in var_value:
+            if var_value and type(var_value) == str and var_value.startswith('$'):
                 var_value = self.execution_vars[var_value[1:]]
 
-            if var_key and '$' in var_key:
+            if var_key and type(var_key) == str and var_key.startswith('$'):
                 var_key = self.execution_vars[var_key[1:]]
             if var_type == 'list':
                 self.execution_vars[var_name].remove(var_value)
@@ -463,7 +463,7 @@ class WebSiteScarperWorker(WorkerAbstract):
 
         pre_defined_sub_data = []
         for pre_def_header, pre_def_val in pre_defined_columns.items():
-            if '$' in pre_def_val:
+            if pre_def_val and type(pre_def_val) == str and pre_def_val.startswith('$'):
                 value = pre_def_val[1:]
 
                 # treating a list value
@@ -651,7 +651,11 @@ class WebSiteScarperWorker(WorkerAbstract):
         pre_def_columns_completed = dict()
         for key, val in pre_defined_columns.items():
             regexp_res = re.search(r"\[([A-Za-z0-9_]+)\]", val)
-            pre_def_columns_completed[key] = branch[int(regexp_res.group(1))].text if type(branch[int(regexp_res.group(1))]) != str else branch[int(regexp_res.group(1))]
+            index = int(regexp_res.group(1))
+            if index < len(branch):
+                pre_def_columns_completed[key] = branch[index].text if type(branch[index]) != str else branch[index]
+            else:
+                pre_def_columns_completed[key] = 'No Data found'
 
         if html_table_idx:
             return self.table2csv(soup=branch[html_table_idx], pre_defined_columns=pre_def_columns_completed)
@@ -712,7 +716,7 @@ def test():
     #ws_scraper.work({'params':{"service_name":"AWS bla"},'payload':{'scrap_flow':'../awsapiactionurl_scrap_flow.yml', 'url_to_scrap':'https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonappflow.html'}})
     #ws_scraper.work({'params': {}, 'payload': {'scrap_flow': '../aws_iam_services_scraper.yml','url_to_scrap': 'https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_aws-services-that-work-with-iam.html'}})
     #ws_scraper.work({'params': {'worker_driver': 'WebSitesScrapingWorker', 'title': 'adHoc'}, 'payload': {'scrap_flow': 'scraper_flows/azure_root_url_scrap.yml', 'url_to_scrap': 'https://docs.microsoft.com/en-us/rest/api/?view=Azure'}})
-    ws_scraper.work( {'params': {'worker_driver': 'WebSitesScrapingWorker', 'title': 'Service Bus'}, 'payload': {'scrap_flow': 'scraper_flows/azure_single_action_doc_scraper.yml', 'url_to_scrap': 'https://docs.microsoft.com/en-us/rest/api/servicebus/delete-namespace'}})
+    ws_scraper.work({'params': {'worker_driver': 'WebSitesScrapingWorker', 'title': 'Application Insights'}, 'payload': {'scrap_flow': 'scraper_flows/azure_single_action_doc_scraper.yml', 'url_to_scrap': 'https://dev.applicationinsights.io/documentation/Using-the-API/Metrics'}})
 
 
 
